@@ -5,6 +5,7 @@ use DBIx::Inspector;
 use Teng::Schema;
 use Teng::Schema::Table;
 use Carp ();
+use Class::Load ();
 
 sub load {
     my $class = shift;
@@ -12,6 +13,12 @@ sub load {
 
     my $namespace = $args{namespace} or Carp::croak("missing mandatory parameter 'namespace'");
 
+    Class::Load::load_optional_class($namespace) or do {
+        # make teng class automatically
+        require Teng;
+        no strict 'refs'; @{"$namespace\::ISA"} = ('Teng');
+    };
+
     my $teng = $namespace->new(%args);
     my $dbh = $teng->dbh;
     unless ($dbh) {
